.. _all-salt.clouds:

===============================
Full list of Salt Cloud modules
===============================

.. currentmodule:: salt.cloud.clouds

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    aliyun
    botocore_aws
    cloudstack
    digital_ocean
    ec2
    gce
    gogrid
    joyent
    libcloud_aws
    linode
    lxc
    msazure
    nova
    opennebula
    openstack
    parallels
    proxmox
    rackspace
    saltify
    softlayer
    softlayer_hw
    vsphere
